==> ldaptive-1.0.13-sources.jar: org/ldaptive/props/BindAuthenticationHandlerPropertySource.java <==
/*
  $Id: BindAuthenticationHandlerPropertySource.java 2885 2014-02-05 21:28:49Z dfisher $

  Copyright (C) 2003-2014 Virginia Tech.
  All rights reserved.

  SEE LICENSE FOR MORE INFORMATION

  Author:  Middleware Services
  Email:   middleware@vt.edu
  Version: $Revision: 2885 $
  Updated: $Date: 2014-02-05 16:28:49 -0500 (Wed, 05 Feb 2014) $
*/
package org.ldaptive.props;

import java.io.Reader;
import java.util.Properties;
import java.util.Set;
import org.ldaptive.auth.BindAuthenticationHandler;

/**
 * Reads properties specific to {@link BindAuthenticationHandler} and returns an
 * initialized object of that type.
 *
 * @author  Middleware Services
 * @version  $Revision: 2885 $ $Date: 2014-02-05 16:28:49 -0500 (Wed, 05 Feb 2014) $
 */
public final class BindAuthenticationHandlerPropertySource
  extends AbstractPropertySource<BindAuthenticationHandler>
{

  /** Invoker for bind authentication handler. */
  private static final BindAuthenticationHandlerPropertyInvoker INVOKER =
    new BindAuthenticationHandlerPropertyInvoker(
      BindAuthenticationHandler.class);


  /**
   * Creates a new bind authentication handler property source using the default
   * properties file.
   *
   * @param  handler  bind authentication handler to invoke properties on
   */
  public BindAuthenticationHandlerPropertySource(
    final BindAuthenticationHandler handler)
  {
    this(handler, PROPERTIES_FILE);
  }


  /**
   * Creates a new bind authentication handler property source.
   *
   * @param  handler  bind authentication handler to invoke properties on
   * @param  paths  to read properties from
   */
  public BindAuthenticationHandlerPropertySource(
    final BindAuthenticationHandler handler,
    final String... paths)
  {
    this(handler, loadProperties(paths));
  }


  /**
   * Creates a new bind authentication handler property source.
   *
   * @param  handler  bind authentication handler to invoke properties on
   * @param  readers  to read properties from
   */
  public BindAuthenticationHandlerPropertySource(
    final BindAuthenticationHandler handler,
    final Reader... readers)
  {
    this(handler, loadProperties(readers));
  }


  /**
   * Creates a new bind authentication handler property source.
   *
   * @param  handler  bind authentication handler to invoke properties on
   * @param  props  to read properties from
   */
  public BindAuthenticationHandlerPropertySource(
    final BindAuthenticationHandler handler,
    final Properties props)
  {
    this(handler, PropertyDomain.AUTH, props);
  }


  /**
   * Creates a new bind authentication handler property source.
   *
   * @param  handler  bind authentication handler to invoke properties on
   * @param  domain  that properties are in
   * @param  props  to read properties from
   */
  public BindAuthenticationHandlerPropertySource(
    final BindAuthenticationHandler handler,
    final PropertyDomain domain,
    final Properties props)
  {
    super(handler, domain, props);
  }


  /** {@inheritDoc} */
  @Override
  public void initialize()
  {
    initializeObject(INVOKER);
  }


  /**
   * Returns the property names for this property source.
   *
   * @return  all property names
   */
  public static Set<String> getProperties()
  {
    return INVOKER.getProperties();
  }
}

==> ldaptive-1.3.0-sources.jar: org/ldaptive/props/BindAuthenticationHandlerPropertySource.java <==
/* See LICENSE for licensing and NOTICE for copyright. */
package org.ldaptive.props;

import java.io.Reader;
import java.util.Properties;
import java.util.Set;
import org.ldaptive.auth.BindAuthenticationHandler;

/**
 * Reads properties specific to {@link BindAuthenticationHandler} and returns an initialized object of that type.
 *
 * @author  Middleware Services
 */
public final class BindAuthenticationHandlerPropertySource extends AbstractPropertySource<BindAuthenticationHandler>
{

  /** Invoker for bind authentication handler. */
  private static final BindAuthenticationHandlerPropertyInvoker INVOKER = new BindAuthenticationHandlerPropertyInvoker(
    BindAuthenticationHandler.class);


  /**
   * Creates a new bind authentication handler property source using the default properties file.
   *
   * @param  handler  bind authentication handler to invoke properties on
   */
  public BindAuthenticationHandlerPropertySource(final BindAuthenticationHandler handler)
  {
    this(handler, PROPERTIES_FILE);
  }


  /**
   * Creates a new bind authentication handler property source.
   *
   * @param  handler  bind authentication handler to invoke properties on
   * @param  paths  to read properties from
   */
  public BindAuthenticationHandlerPropertySource(final BindAuthenticationHandler handler, final String... paths)
  {
    this(handler, loadProperties(paths));
  }


  /**
   * Creates a new bind authentication handler property source.
   *
   * @param  handler  bind authentication handler to invoke properties on
   * @param  readers  to read properties from
   */
  public BindAuthenticationHandlerPropertySource(final BindAuthenticationHandler handler, final Reader... readers)
  {
    this(handler, loadProperties(readers));
  }


  /**
   * Creates a new bind authentication handler property source.
   *
   * @param  handler  bind authentication handler to invoke properties on
   * @param  props  to read properties from
   */
  public BindAuthenticationHandlerPropertySource(final BindAuthenticationHandler handler, final Properties props)
  {
    this(handler, PropertyDomain.AUTH, props);
  }


  /**
   * Creates a new bind authentication handler property source.
   *
   * @param  handler  bind authentication handler to invoke properties on
   * @param  domain  that properties are in
   * @param  props  to read properties from
   */
  public BindAuthenticationHandlerPropertySource(
    final BindAuthenticationHandler handler,
    final PropertyDomain domain,
    final Properties props)
  {
    super(handler, domain, props);
  }


  @Override
  public void initialize()
  {
    initializeObject(INVOKER);
  }


  /**
   * Returns the property names for this property source.
   *
   * @return  all property names
   */
  public static Set<String> getProperties()
  {
    return INVOKER.getProperties();
  }
}
